@@ -7,7 +7,7 @@ from operator import itemgetter
 
 import getpass
 
-__version__ = '0.4.0'
+__version__ = '0.4.3'
 
 
 class Storm(object):
@@ -16,22 +16,22 @@ class Storm(object):
         self.ssh_config = ConfigParser(ssh_config_file)
         self.ssh_config.load()
 
-    def add_entry(self, name, host, user, port, id_file):
+    def add_entry(self, name, host, user, port, id_file, custom_options=[]):
         if self.is_host_in(name):
             raise StormValueError('{0} is already in your sshconfig. use storm edit command to modify.'.format(name))
 
-        options = self.get_options(host, user, port, id_file)
+        options = self.get_options(host, user, port, id_file, custom_options)
 
         self.ssh_config.add_host(name, options)
         self.ssh_config.write_to_ssh_config()
 
         return True
 
-    def edit_entry(self, name, host, user, port, id_file):
+    def edit_entry(self, name, host, user, port, id_file, custom_options=[]):
         if not self.is_host_in(name):
             raise StormValueError('{0} doesn\'t exists in your sshconfig. use storm add command to add.'.format(name))
 
-        options = self.get_options(host, user, port, id_file)
+        options = self.get_options(host, user, port, id_file, custom_options)
         self.ssh_config.update_host(name, options)
         self.ssh_config.write_to_ssh_config()
 
@@ -59,7 +59,7 @@ class Storm(object):
         results = self.ssh_config.search_host(search_string)
         formatted_results = []
         for host_entry in results:
-            formatted_results.append("  {0} -> {1}@{2}:{3}\n".format(
+            formatted_results.append("    {0} -> {1}@{2}:{3}\n".format(
                 host_entry.get("host"),
                 host_entry.get("options").get("user", getpass.getuser()),
                 host_entry.get("options").get("hostname"),
@@ -68,7 +68,7 @@ class Storm(object):
 
         return formatted_results
 
-    def get_options(self, host, user, port, id_file):
+    def get_options(self, host, user, port, id_file, custom_options):
         options = {
             'hostname': host,
             'user': user,
@@ -80,6 +80,14 @@ class Storm(object):
                 'identityfile': id_file,
             })
 
+        if len(custom_options) > 0:
+            for custom_option in custom_options:
+                if '=' in custom_option:
+                    key, value = custom_option.split("=")[0:2]
+                options.update({
+                    key: value,
+                })
+
         return options
 
     def is_host_in(self, host):
